## cdist-type__timezone(7)

### Ramon Salvadó

`<rsalvado--@--gnuine--dot--com>`

## 1. NAME

cdist-type__timezone - Allows to configure the desired localtime timezone.

## 2. DESCRIPTION

This type creates a symlink (/etc/localtime) to the selected timezone (which should be available in /usr/share/zoneinfo).

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

None.

## 5. EXAMPLES

    #Set up Europe/Andorra as our timezone.
    __timezone Europe/Andorra

    #Set up US/Central as our timezone.
    __timezone US/Central

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).